#
# spec file for package rtw89
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild

%{?!_firmwaredir:%define _firmwaredir /lib/firmware}

Name:           rtw89
Version:        5.16~3.g38316db
Release:        lp153.4.1
Summary:        Driver for Realtek 8852AE Wifi chip
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://github.com/lwfinger/rtw89
Source0:        %{name}-%{version}.tar
Source1:        preamble
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  pesign-obs-integration
%kernel_module_package -n rtw89 -x debug -x trace -c %{_sourcedir}/_projectcert.crt -p %{_sourcedir}/preamble

%description
A driver for the Realtek 8852AE. Wifi chip with
802.11ax / Wi-Fi 6 support.

%package firmware
Summary:        Firmware for Realtek 8852AE Wifi chip
License:        SUSE-Firmware

%description firmware
Firmware for the Realtek 8852AE. Wifi chip with
802.11ax / Wi-Fi 6 support.

%prep
%setup -q

set -- *
mkdir source
mv "$@" source/
mkdir obj

%build
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
[ -n "$SOURCE_DATE_EPOCH" ] && export KBUILD_BUILD_TIMESTAMP=@$SOURCE_DATE_EPOCH
for flavor in %{flavors_to_build}; do
	rm -rf obj/$flavor
	cp -r source obj/$flavor
	%make_build -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules \
	     M=$PWD/obj/$flavor
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates/rtw89/
export BRP_PESIGN_FILES='*.ko'
export BRP_PESIGN_COMPRESS_MODULE="xz"

for flavor in %{flavors_to_build}; do
	make -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules_install \
		M=$PWD/obj/$flavor
done

install -d -m 755 %{buildroot}%{_firmwaredir}/rtw89
install -m 644 -t %{buildroot}%{_firmwaredir}/rtw89 source/*.bin

%files firmware
%{_firmwaredir}/rtw89

%changelog
* Thu Oct 28 2021 Michal Suchanek <msuchanek@suse.de>
- Run through spec-cleaner, use firmwaredir.
* Mon Oct 25 2021 mwilck@suse.com
- Update to version 5.16~3.g38316db:
  * remove leap153.patch (Upstream needs no patches any more for
    Leap 15.3 and 15.2 - boo#1191321)
  * build fixes for older kernels
* Fri Oct 22 2021 Martin Wilck <mwilck@suse.com>
- Use SOURCE_DATE_EPOCH for reproducible builds
* Fri Oct 22 2021 mwilck@suse.com
- New versioning scheme: kernel version in which this code base is
  likely to be merged + pre-release number + git hash
- Use OBS source services
- Update to version 5.16~1.gd338cdb
  (sources are identical to previous package)
* Thu Oct 21 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- rtw89: Fix builds for kernels 5.9 and older
- rtw89: Conditionalize references to he_mcs[]
- rtw89: Fix build for kernels < 5.8
    Also fix a typo.
* Thu Oct 21 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- added a new patch to get building on Leap 15.3 ( thanks Larry Finger)
  * add leap153.patch
* Tue Oct 19 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- switched to rtw89 Version 7
* Sat Oct  2 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
  * rtw89: Check sec_cam in rtw89_cam_sec_key_del()
    There are sometimes NULL dereference BUGS on disconnect. The traceback points to
    sec_cam_idx = sec_cam->sec_cam_idx as the offending statement. Check these pointers
    at entry.
* Fri Sep 17 2021 Martin Wilck <martin.wilck@suse.com>
- Added subpackage for firmware
* Fri Sep 17 2021 Martin Wilck <mwilck@suse.com>
- Spec file update
  * Skip initrd rebuilding (hardly necessary for wifi)
  * Add module signing
  * Always use multiple jobs if possible
  * Remove superflous Obsoletes:, Conflicts:, and Provides:
    (this is handled by kernel-module-subpackage)
* Wed Aug 18 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Update to Version 20210817
  * Add Makefile target to sign kernel modules for SecureBoot
  * Makefile: add .PHONY target
  * rtw89: The fix for 32-bit systems is wrong
  Rather than do_div(), we should use DIV_ROUND_DOWN_ULL().
  * rtw89: Fix divide problem on 32-bit systems
  The driver does two 64-bit divides. These are OK on a 64-bit system, but
  lead to a missing routine __udivdi3. The fix is to replace those divisions
    with a call to do_div(). With that, the kernel does the right thing.
  * rtw89: Patch to permit IPv6 operation
* Sun Jul 25 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Update to Version 20210725
  * rtw89: Supply script to unload the driver before hibernation/sleep
    The script reloads the driver upon resumption. README.md is updated.
  * rtw89: Trial fix for problem with AMD
* Mon Jul 19 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Update to version 20210719
  * rtw89: Add patch that might improve connectivity
  * rtw89: Make certain that firmware direttory exists
  * rtw89: Update source and firmware for PCI ID 10ec:a85a
  * rtw89: Fix builds for kernel v5.4
  * rtw89: Fix builds for kernel v5.6
* Sat Jul  3 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Update the Source to Version 5
* Thu Jul  1 2021 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Initial build
